@@ -30,10 +30,16 @@ datasummary_balance <- function(formula,
                                 add_rows = NULL,
                                 dinm = TRUE,
                                 dinm_statistic = "std.error",
+                                escape = TRUE,
                                 ...) {
+  ## settings 
+  settings_init(settings = list(
+     "function_called" = "datasummary_balance"
+  ))
 
   # sanity checks
-  sanity_output(output)
+  sanitize_escape(escape)
+  sanitize_output(output)
   sanity_ds_right_handed_formula(formula)
   checkmate::assert_formula(formula)
   checkmate::assert_data_frame(data, min.rows = 1, min.cols = 1)
@@ -77,11 +83,11 @@ datasummary_balance <- function(formula,
   }
 
   if (any_factor) {
-    tab_fac <- datasummary_balance_factor(rhs, data, data_norhs, any_numeric)
+    tab_fac <- datasummary_balance_factor(rhs, data, data_norhs, any_numeric, output, escape)
   }
 
   if (any_numeric) {
-    tab_num <- datasummary_balance_numeric(rhs, data, data_norhs, fmt, dinm, dinm_statistic)
+    tab_num <- datasummary_balance_numeric(rhs, data, data_norhs, fmt, dinm, dinm_statistic, output, escape)
   }
 
   if (any_numeric && any_factor) {
@@ -92,7 +98,7 @@ datasummary_balance <- function(formula,
     for (i in seq_along(header)) {
       header[1, i] <- ifelse(!cols[i] %in% c("Mean", "Std. Dev."), "", header[1, i])
       header[1, i] <- ifelse(cols[i] == "Mean", "N", header[1, i])
-      header[1, i] <- ifelse(cols[i] == "Std. Dev.", "%", header[1, i])
+      header[1, i] <- ifelse(cols[i] == "Std. Dev.", "Pct.", header[1, i])
     }
     tab_fac <- bind_rows(header, tab_fac)
 
@@ -129,8 +135,14 @@ datasummary_balance <- function(formula,
     hrule <- NULL
   }
 
+  # align: default (TODO: `add_columns` support)
+  if (is.null(align) && !is.null(attr(tab, "stub_width")) && is.null(add_columns)) {
+    align <- paste0(strrep("l", attr(tab, "stub_width")),
+                    strrep("r", ncol(tab) - attr(tab, "stub_width")))
+  }
+
   # make table
-  factory(
+  out <- factory(
     tab,
     align = align,
     hrule = hrule,
@@ -142,9 +154,17 @@ datasummary_balance <- function(formula,
     title = title,
     ...)
 
+  if (!is.null(settings_get("output_file"))) {
+    settings_rm()
+    return(invisible(out))
+  } else {
+    settings_rm()
+    return(out)
+  }
+
 }
 
-datasummary_balance_factor <- function(rhs, data, data_norhs, any_numeric) {
+datasummary_balance_factor <- function(rhs, data, data_norhs, any_numeric, output, escape) {
 
   # formatting function
   pctformat = function(x) sprintf("%.1f", x)
@@ -175,19 +195,21 @@ datasummary_balance_factor <- function(rhs, data, data_norhs, any_numeric) {
   # formula
   f_fac <- 'All(data_norhs, factor = TRUE, numeric = FALSE) ~
             Factor(%s) * (Heading("N")*1 * Format() +
-            Heading("%%") * Percent("col") * Format(pctformat()))'
+            Heading("Pct.") * Percent("col") * Format(pctformat()))'
   f_fac <- sprintf(f_fac, rhs)
 
   if (any_numeric) { # before removing numerics
-    f_fac <- gsub('\\"\\%\\"', '\\"Std. Dev.\\"', f_fac)
+    f_fac <- gsub('\\"Pct.\\"', '\\"Std. Dev.\\"', f_fac)
     f_fac <- gsub('\\"N\\"', '\\"Mean\\"', f_fac)
   }
   f_fac <- stats::formula(f_fac)
 
-  # process
+  # process & reset output settings (datasummary sets "data.frame")
   tab_fac <- datasummary(f_fac,
                          data = data,
-                         output = "data.frame")
+                         output = "data.frame",
+                         escape = escape)
+  sanitize_output(output)
 
   # cleanup
   colnames(tab_fac) <- pad(attr(tab_fac, "header_bottom"))
@@ -201,14 +223,18 @@ datasummary_balance_factor <- function(rhs, data, data_norhs, any_numeric) {
 }
 
 
-datasummary_balance_numeric <- function(rhs, data, data_norhs, fmt, dinm, dinm_statistic) {
+datasummary_balance_numeric <- function(rhs, data, data_norhs, fmt, dinm, dinm_statistic, output, escape) {
 
   # create table as data.frame
   f_num <- sprintf(
     'All(data_norhs) ~ Factor(%s) * (Mean + Heading("Std. Dev.") * SD) * Arguments(fmt = fmt)',
     rhs)
   f_num <- stats::formula(f_num)
-  tab_num <- datasummary(f_num, data = data, output = "data.frame")
+
+  # process & reset output settings (datasummary sets "data.frame")
+  tab_num <- datasummary(f_num, data = data, output = "data.frame", escape = escape)
+  sanitize_output(output)
+
 
   # otherwise colnames: female (N=140) Mean
   colnames(tab_num) <- pad(attr(tab_num, "header_bottom"))
